summaryrefslogtreecommitdiffstats
path: root/src/H5SLprivate.h
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2004-12-30 16:26:45 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2004-12-30 16:26:45 (GMT)
commit7fae6be03c428a29bdeb9586663a3193e2268bf5 (patch)
treeda94aadd11293e088ef8af6741b2f0bffc6f0b59 /src/H5SLprivate.h
parenta56a1205d25b9184d628a30886ed4a0801d3ec94 (diff)
downloadhdf5-7fae6be03c428a29bdeb9586663a3193e2268bf5.zip
hdf5-7fae6be03c428a29bdeb9586663a3193e2268bf5.tar.gz
hdf5-7fae6be03c428a29bdeb9586663a3193e2268bf5.tar.bz2
[svn-r9734] Purpose:
Code cleanup Description: Convert chunk iteration code to use skip lists instead of threaded, balanced binary trees. Platforms tested: FreeBSD 4.10 (sleipnir) w/parallel & szip Too minor to require h5committest
Diffstat (limited to 'src/H5SLprivate.h')
-rw-r--r--src/H5SLprivate.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/H5SLprivate.h b/src/H5SLprivate.h
index 43367fb..f3944f4 100644
--- a/src/H5SLprivate.h
+++ b/src/H5SLprivate.h
@@ -42,7 +42,8 @@ typedef struct H5SL_node_t H5SL_node_t;
typedef enum {
H5SL_TYPE_INT, /* Skip list keys are 'int's */
H5SL_TYPE_HADDR, /* Skip list keys are 'haddr_t's */
- H5SL_TYPE_STR /* Skip list keys are 'char *'s (ie. strings) */
+ H5SL_TYPE_STR, /* Skip list keys are 'char *'s (ie. strings) */
+ H5SL_TYPE_HSIZE /* Skip list keys are 'hsize_t's */
} H5SL_type_t;
/**********/
@@ -59,7 +60,7 @@ typedef herr_t (*H5SL_operator_t)(void *item, void *key,
/********************/
H5_DLL H5SL_t *H5SL_create(H5SL_type_t type, double p, size_t max_level);
H5_DLL size_t H5SL_count(H5SL_t *slist);
-H5_DLL herr_t H5SL_insert(H5SL_t *slist, void *item, void *key);
+H5_DLL herr_t H5SL_insert(H5SL_t *slist, void *item, const void *key);
H5_DLL void *H5SL_remove(H5SL_t *slist, const void *key);
H5_DLL void *H5SL_search(H5SL_t *slist, const void *key);
H5_DLL H5SL_node_t *H5SL_first(H5SL_t *slist);